# -*- coding: utf-8 -*-

import json
import datetime

UPDATE_RATE_CONFIG = "/var/cache/kylin-system-updater/rate_limites.json"
P2P_RATE_CONFIG = "/var/cache/apt-p2p/p2p_rate_limites.json"

def is_within_rate_limit(params):
    download_rate = None
    p2p_upload_rate = None

    current_time = datetime.datetime.now().time()

    policy_limits = params.setdefault("policy_limits",False)
    # 分时限速策略
    if policy_limits:
        rate_limits = params.get("rate_limits",[])
        for limit in rate_limits:
            if not isinstance(limit, dict):
                break
            time_period = limit.get("time_period","")
            if time_period == 'daily':
                if "start_time" not in limit or "end_time" not in limit:
                    break
                start_time = datetime.datetime.strptime(limit['start_time'], "%H:%M").time()
                end_time = datetime.datetime.strptime(limit['end_time'], "%H:%M").time()

                if start_time <= current_time <= end_time:
                    if "download_limit" in limit:
                        download_rate = limit['download_limit']
                    if "upload_limit" in limit:
                        p2p_upload_rate = limit['upload_limit']
                if download_rate or p2p_upload_rate:
                    break

    if not download_rate:
        download_rate = params.setdefault("default_download",0)
    
    if not p2p_upload_rate:
        p2p_upload_rate = params.setdefault("default_upload",0)

    # 检查是否为存数字 存在其他字符是跳出 默认不进行限速
    p2p_upload_rate = str(p2p_upload_rate).strip()
    if not p2p_upload_rate.isdigit():
        p2p_upload_rate = "0"
    download_rate = str(download_rate).strip()
    if not download_rate.isdigit():
        download_rate = "0"

    return download_rate,p2p_upload_rate

def update_rate_limit():
    with open(UPDATE_RATE_CONFIG, 'r') as config_file:
        rate_config = json.load(config_file)

    return is_within_rate_limit(rate_config)
    
def p2p_rate_limit():
    with open(P2P_RATE_CONFIG, 'r') as config_file:
        rate_config = json.load(config_file)

    return is_within_rate_limit(rate_config)

def set_p2p_rate_config(data):
    with open(P2P_RATE_CONFIG, 'w') as config_file:
        json.dump(data, config_file, indent=4)

def set_update_rate_config(data):
    with open(UPDATE_RATE_CONFIG, 'w') as config_file:
        json.dump(data, config_file, indent=4)